@@ -29,7 +29,7 @@
  *
  * kspeech - the KDE Text-to-Speech API.
  *
- * @version 1.0 Draft 9
+ * @version 1.0 Draft 10
  *
  * @since KDE 3.4
  *
@@ -45,7 +45,7 @@
  *
  *   - Priority system for Screen Readers, warnings and messages, while still playing
  *     regular texts.
- *   - Long text is parsed into sentences.  User may backup by sentence or part, 
+ *   - Long text is parsed into sentences.  User may backup by sentence or part,
  *     replay, pause, and stop playing.
  *   - Handles multiple speaking applications.  Text messages are treated like print jobs.
  *     Jobs may be created, started, stopped, paused, resumed, and deleted.
@@ -105,7 +105,7 @@
         speech engine
    @endverbatim
  *
- * The %KTTSD Plugin API is documented in @ref PluginConf in the kdeaccessibility module.
+ * The %KTTSD Plugin API is documented in PluginConf in the kdeaccessibility module.
  *
  * There is a separate GUI application, called kttsmgr, for providing %KTTSD
  * configuration and job management.
@@ -116,24 +116,24 @@
  *   - Messages
  *   - Text Jobs
  *
- * Method @ref sayScreenReaderOutput speaks Screen Reader output.
+ * Method sayScreenReaderOutput speaks Screen Reader output.
  * It pre-empts any other speech in progress,
- * including other Screen Reader outputs, i.e., it is not a queue.  
+ * including other Screen Reader outputs, i.e., it is not a queue.
  * This method is reserved for use by Screen Readers.
  *
- * Methods @ref sayWarning and @ref sayMessage place messages into the Warnings and
+ * Methods sayWarning and sayMessage place messages into the Warnings and
  * Messages queues respectively.  Warnings take priority over messages, which take priority
  * over text jobs.  Warnings and messages are spoken when the currently-speaking
  * sentence of a text job is finished.
  *
- * @ref setText places text into the text job queue. @ref startText begins speaking jobs.
- * When one job finishes, the next job begins.  Method @ref appendText adds
+ * setText places text into the text job queue. startText begins speaking jobs.
+ * When one job finishes, the next job begins.  Method appendText adds
  * additional parts to a text job.  Within a text job, the application (and user
  * via the kttsmgr GUI), may back up or advance by sentence or part, or rewind
  * to the beginning.
- * See @ref jumpToTextPart and @ref moveRelTextSentence.
+ * See jumpToTextPart and moveRelTextSentence.
  * Text jobs may be paused, stopped, and resumed or deleted from the queue.
- * See @ref pauseText, @ref stopText, @ref resumeText, and @ref removeText.
+ * See pauseText, stopText, resumeText, and removeText.
  *
  * @section cmdline DCOP Command-line Interface
  *
@@ -158,6 +158,14 @@
      dcop kttsd KSpeech startText 0
    @endverbatim
  *
+ * You can combine the setText and startText commands into a single command.
+ *
+   @verbatim
+     dcop kttsd KSpeech sayText <text> <talker>
+   @endverbatim
+ *
+ * @since KDE 3.5
+ *
  * To stop speaking and rewind to the beginning of the text.
  *
    @verbatim
@@ -172,7 +180,7 @@
      dcop kttsd KSpeech removeText 0
    @endverbatim
  *
- * Note: For more information about talker codes, see @ref talkers below.
+ * Note: For more information about talker codes, see talkers below.
  *
  * @section programming Calling KTTSD from a Program
  *
@@ -216,6 +224,18 @@
      }
    @endverbatim
  *
+ * If you want to detect if KTTSD is installed without starting it, use this code.
+ *
+   @verbatim
+     KTrader::OfferList offers = KTrader::self()->query("DCOP/Text-to-Speech", "Name == 'KTTSD'");
+     if (offers.count() > 0)
+     {
+       // KTTSD is installed.
+     }
+   @endverbatim
+ *
+ * Typically, you would do this to hide a menu item or button if KTTSD is not installed.
+ *
  * 4.  Make calls to KTTSD in your code.
  *
    @verbatim
@@ -228,7 +248,7 @@
    @verbatim
      kspeech_DIR = $(kde_includes)
      libmypart_la_SOURCES = kspeech.stub
-   @endverbatim 
+   @endverbatim
  *
  * @section signals Signals Emitted by KTTSD
  *
@@ -258,7 +278,7 @@
  *
    @verbatim
      #include <kspeechsink.h>
-     class MyPart: 
+     class MyPart:
          public KParts::ReadOnlyPart,
          public KSpeech_stub,
          virtual public KSpeechSink
@@ -290,7 +310,7 @@
      if (!client->isRegistered())
      {
          client->attach();
-         client->registerAs(kapp->name());    
+         client->registerAs(kapp->name());
      }
      // Connect KTTSD DCOP signals to our slots.
      connectDCOPSignal("kttsd", "KSpeech",
@@ -403,7 +423,7 @@
  *
  *   lang="en" gender="female"
  *
- * If the talker code is not in XML attribute format, it assumed to be a @e lang 
+ * If the talker code is not in XML attribute format, it assumed to be a @e lang
  * attribute.  So the talker code
  *
  *   en
@@ -412,8 +432,8 @@
  *
  *   lang="en"
  *
- * When a program requests a talker code in calls to @ref setText, @ref appendText,
- * @ref sayMessage, @ref sayWarning, and @ref sayScreenReaderOutput,
+ * When a program requests a talker code in calls to setText, appendText,
+ * sayMessage, sayWarning, and sayScreenReaderOutput,
  * %KTTSD tries to match the requested talker code to the closest matching
  * configured talker.
  *
@@ -486,11 +506,11 @@
  * it sounds terrible, user will change his configuration.)
  * If an attribute is absolutely mandatory -- in other words the application
  * must speak with the attribute or not at all -- the application can determine if
- * there are any talkers configured with the attribute by calling @ref getTalkers,
+ * there are any talkers configured with the attribute by calling getTalkers,
  * and if there are none, display an error message to the user.
  *
  * Applications can implement their own talker-matching algorithm by
- * calling @ref getTalkers, then finding the desired talker from the returned
+ * calling getTalkers, then finding the desired talker from the returned
  * list.  When the full talker code is passed in, %KKTSD will find an exact
  * match and use the specified talker.
  *
@@ -499,7 +519,7 @@
  * configure the desired talker.  (This must be done interactively because
  * plugins often need user assistance locating voice files, etc.)
  *
- * The above scheme is designed to balance the needs 
+ * The above scheme is designed to balance the needs
  * of applications against user preferences.  Applications are given the control
  * they @e might need, without unnecessarily burdening the application author.
  * If you are an application author, the above discussion might seem overly
@@ -512,7 +532,7 @@
  *   - If there is an attribute your application @e requires for proper functioning,
  *     specify that with an asterisk in front of it.  For example, your app might
  *     speak in two different voices, Male and Female.  (Since your
- *     app requires both genders, call @ref getTalkers to determine if both genders
+ *     app requires both genders, call getTalkers to determine if both genders
  *     are available, and if not, advise user to configure them.  Better yet,
  *     give the user a choice of available distinquishing attributes
  *     (loud/soft, fast/slow, etc.)
@@ -530,9 +550,8 @@
  *
  * Note: %Speech Markup is not yet fully implemented in %KTTSD.
  *
- * Each of the five methods for queueing text to be spoken -- @ref sayScreenReaderOutput,
- * @ref setText, @ref appendText, @ref sayMessage, and
- * @ref sayWarning -- may contain speech markup,
+ * Each of the five methods for queueing text to be spoken -- sayScreenReaderOutput,
+ * setText, appendText, sayMessage, and sayWarning -- may contain speech markup,
  * provided that the plugin the user has configured supports that markup.  The markup
  * languages and plugins currently supported are:
  *
@@ -541,8 +560,8 @@
  * This may change in the future as synthesizers improve.
  *
  * Before including markup in the text sent to kttsd, the application should
- * query whether the currently-configured plugin 
- * supports the markup language by calling @ref supportsMarkup.
+ * query whether the currently-configured plugin
+ * supports the markup language by calling supportsMarkup.
  *
  * It it does not support the markup, it will be stripped out of the text.
  *
@@ -552,17 +571,17 @@
  *
  * When using a speech markup language, such as Sable, JSML, or SSML, the application may embed
  * named markers into the text.  If the user's chosen speech plugin supports markers, %KTTSD
- * will emit DCOP signal @ref markerSeen when the speech engine encounters the marker.
+ * will emit DCOP signal markerSeen when the speech engine encounters the marker.
  * Depending upon the speech engine and plugin, this may occur either when the speech engine
  * encounters the marker during synthesis from text to speech, or when the speech is actually
- * spoken on the audio device.  The calling application can call the @ref supportsMarkers
+ * spoken on the audio device.  The calling application can call the supportsMarkers
  * method to determine if the currently configured plugin supports markers or not.
  *
  * @section sentenceparsing Sentence Parsing
  *
  * Not all speech engines provide robust capabilities for stopping synthesis that is in progress.
- * To compensate for this, %KTTSD parses text jobs given to it by the @ref setText and 
- * @ref appendText methods into sentences and sends the sentences to the speech
+ * To compensate for this, %KTTSD parses text jobs given to it by the setText and
+ * appendText methods into sentences and sends the sentences to the speech
  * plugin one at a time.  In this way, should the user wish to stop the speech
  * output, they can do so, and the worst that will happen is that the last sentence
  * will be completed.  This is called Sentence Boundary Detection (SBD).
@@ -579,14 +598,40 @@
  * When given text containing speech markup, %KTTSD automatically determines the markup type
  * and parses based on the sentence semantics of the markup language.
  *
- * An application may change the sentence delimiter by calling @ref setSentenceDelimiter
- * prior to calling @ref setText.  Changing the delimiter does not affect other
+ * An application may change the sentence delimiter by calling setSentenceDelimiter
+ * prior to calling setText.  Changing the delimiter does not affect other
  * applications.
  *
- * Text given to %KTTSD via the @ref sayWarning, @ref sayMessage, and @ref sayScreenReaderOutput
+ * Text given to %KTTSD via the sayWarning, sayMessage, and sayScreenReaderOutput
  * methods is @e not parsed into sentences.  For this reason, applications
  * should @e not send long messages with these methods.
  *
+ * Sentence Boundary Detection is implemented as a plugin SBD filter.  See
+ * filters for more information.
+ *
+ * @section filters Filters
+ *
+ * Users may specify filters in the kttsmgr GUI.  Filters are plugins that modify the text
+ * to be spoken or change other characteristics of jobs.  Currently, the following filter plugins
+ * are available:
+ *
+ *   - String Replacer.  Permits users to substitute for mispoken words, or vocalize chat
+ *     emoticons.
+ *   - XML Transformer.  Given a particular XML or XHTML format, permits conversion of the
+ *     XML to SSML (Speech Synthesis Markup Language) using XSLT (XML Style Language - Transforms)
+ *     stylesheets.
+ *   - Talker Chooser.  Permits users to redirect jobs from one configured Talker to another
+ *     based on the contents of the job or application that sent it.
+ *
+ * Additional plugins may be available in the future.
+ *
+ * In additional to these regular filters, KTTS also implements Sentence Boundary Detection (SBD)
+ * as a plugin filter.  See sentenceparsing for more information.
+ *
+ * Regular filters are applied to Warnings, Messages, and Text jobs.  SBD filters are
+ * only applied to regular Text jobs; they are not applied to Warnings and Messages.  Screen
+ * Reader Outputs are never filtered.
+ *
  * @section authors Authors
  *
  * @author José Pablo Ezequiel "Pupeno" Fernández <pupeno@kde.org>
@@ -603,7 +648,7 @@ class KSpeech : virtual public DCOPObject {
     public:
         /**
         * @enum kttsdJobState
-        * Job states returned by method @ref getTextJobState.
+        * Job states returned by method getTextJobState.
         */
         enum kttsdJobState
         {
@@ -623,7 +668,8 @@ class KSpeech : virtual public DCOPObject {
             mtPlain = 0,                 /**< Plain text */
             mtJsml = 1,                  /**< Java %Speech Markup Language */
             mtSsml = 2,                  /**< %Speech Synthesis Markup Language */
-            mtSable = 3                  /**< Sable 2.0 */
+            mtSable = 3,                 /**< Sable 2.0 */
+            mtHtml = 4                   /**< HTML @since 3.5 */
         };
 
     k_dcop:
@@ -729,15 +775,15 @@ class KSpeech : virtual public DCOPObject {
         * @return               Job number.
         *
         * Plain text is parsed into individual sentences using the current sentence delimiter.
-        * Call @ref setSentenceDelimiter to change the sentence delimiter prior to
+        * Call setSentenceDelimiter to change the sentence delimiter prior to
         * calling setText.
-        * Call @ref getTextCount to retrieve the sentence count after calling setText.
+        * Call getTextCount to retrieve the sentence count after calling setText.
         *
         * The text may contain speech mark language, such as Sable, JSML, or SSML,
         * provided that the speech plugin/engine support it.  In this case,
         * sentence parsing follows the semantics of the markup language.
         *
-        * Call @ref startText to mark the job as speakable and if the
+        * Call startText to mark the job as speakable and if the
         * job is the first speakable job in the queue, speaking will begin.
         *
         * @see getTextCount
@@ -745,6 +791,36 @@ class KSpeech : virtual public DCOPObject {
         */
         virtual uint setText(const QString &text, const QString &talker) = 0;
 
+        /**
+        * Say a plain text job.  This is a convenience method that
+        * combines setText and startText into a single call.
+        * @param text           The message to be spoken.
+        * @param talker         Code for the talker to do the speaking.  Example "en".
+        *                       If NULL, defaults to the user's default plugin.
+        *                       If no plugin has been configured for the specified Talker code,
+        *                       defaults to the closest matching talker.
+        * @return               Job number.
+        *
+        * Plain text is parsed into individual sentences using the current sentence delimiter.
+        * Call setSentenceDelimiter to change the sentence delimiter prior to
+        * calling setText.
+        * Call getTextCount to retrieve the sentence count after calling setText.
+        *
+        * The text may contain speech mark language, such as Sable, JSML, or SSML,
+        * provided that the speech plugin/engine support it.  In this case,
+        * sentence parsing follows the semantics of the markup language.
+        *
+        * The job is marked speakable.
+        * If there are other speakable jobs preceeding this one in the queue,
+        * those jobs continue speaking and when finished, this job will begin speaking.
+        * If there are no other speakable jobs preceeding this one, it begins speaking.
+        *
+        * @see getTextCount
+        *
+        * @since KDE 3.5
+        */
+        virtual uint sayText(const QString &text, const QString &talker) = 0;
+
         /**
         * Adds another part to a text job.  Does not start speaking the text.
         * @param text           The message to be spoken.
@@ -774,14 +850,14 @@ class KSpeech : virtual public DCOPObject {
         * @return               Job number.  0 if an error occurs.
         *
         * Plain text is parsed into individual sentences using the current sentence delimiter.
-        * Call @ref setSentenceDelimiter to change the sentence delimiter prior to calling setText.
-        * Call @ref getTextCount to retrieve the sentence count after calling setText.
+        * Call setSentenceDelimiter to change the sentence delimiter prior to calling setText.
+        * Call getTextCount to retrieve the sentence count after calling setText.
         *
         * The text may contain speech mark language, such as Sable, JSML, or SSML,
         * provided that the speech plugin/engine support it.  In this case,
         * sentence parsing follows the semantics of the markup language.
         *
-        * Call @ref startText to mark the job as speakable and if the
+        * Call startText to mark the job as speakable and if the
         * job is the first speakable job in the queue, speaking will begin.
         *
         * @see getTextCount
@@ -798,8 +874,8 @@ class KSpeech : virtual public DCOPObject {
         * @return               The number of sentences in the job.  -1 if no such job.
         *
         * The sentences of a job are given sequence numbers from 1 to the number returned by this
-        * method.  The sequence numbers are emitted in the @ref sentenceStarted and
-        * @ref sentenceFinished signals.
+        * method.  The sequence numbers are emitted in the sentenceStarted and
+        * sentenceFinished signals.
         */
         virtual int getTextCount(uint jobNum=0) = 0;
 
@@ -807,7 +883,7 @@ class KSpeech : virtual public DCOPObject {
         * Get the job number of the current text job.
         * @return               Job number of the current text job. 0 if no jobs.
         *
-        * Note that the current job may not be speaking. See @ref isSpeakingText.
+        * Note that the current job may not be speaking. See isSpeakingText.
         *
         * @see getTextJobState.
         * @see isSpeakingText
@@ -910,7 +986,7 @@ class KSpeech : virtual public DCOPObject {
         *                       If zero, applies to the last job queued by the application,
         *                       but if no such job, applies to the current job (if any).
         *
-        * The job is deleted from the queue and the @ref textRemoved signal is emitted.
+        * The job is deleted from the queue and the textRemoved signal is emitted.
         *
         * If there is another job in the text queue, and it is marked speakable,
         * that job begins speaking.
@@ -930,9 +1006,9 @@ class KSpeech : virtual public DCOPObject {
         * those jobs continue speaking and when finished, this job will begin speaking.
         * If there are no other speakable jobs preceeding this one, it begins speaking.
         *
-        * The @ref textStarted signal is emitted when the text job begins speaking.
+        * The textStarted signal is emitted when the text job begins speaking.
         * When all the sentences of the job have been spoken, the job is marked for deletion from
-        * the text queue and the @ref textFinished signal is emitted.
+        * the text queue and the textFinished signal is emitted.
         */
         virtual ASYNC startText(uint jobNum=0) = 0;
 
@@ -942,16 +1018,16 @@ class KSpeech : virtual public DCOPObject {
         *                       If zero, applies to the last job queued by the application,
         *                       but if no such job, applies to the current job (if any).
         *
-        * The job is marked not speakable and will not be speakable until @ref startText
-        * or @ref resumeText is called.
+        * The job is marked not speakable and will not be speakable until startText
+        * or resumeText is called.
         *
         * If there are speaking jobs preceeding this one in the queue, they continue speaking.
         *
-        * If the job is currently speaking, the @ref textStopped signal is emitted,
+        * If the job is currently speaking, the textStopped signal is emitted,
         * the job stops speaking, and if the next job in the queue is speakable, it
         * begins speaking.
         *
-        * Depending upon the speech engine and plugin used, speeking may not stop immediately
+        * Depending upon the speech engine and plugin used, speech may not stop immediately
         * (it might finish the current sentence).
         */
         virtual ASYNC stopText(uint jobNum=0) = 0;
@@ -962,16 +1038,16 @@ class KSpeech : virtual public DCOPObject {
         *                       If zero, applies to the last job queued by the application,
         *                       but if no such job, applies to the current job (if any).
         *
-        * The job is marked as paused and will not be speakable until @ref resumeText or
-        * @ref startText is called.
+        * The job is marked as paused and will not be speakable until resumeText or
+        * startText is called.
         *
         * If there are speaking jobs preceeding this one in the queue, they continue speaking.
         *
-        * If the job is currently speaking, the @ref textPaused signal is emitted and the job
+        * If the job is currently speaking, the textPaused signal is emitted and the job
         * stops speaking.  Note that if the next job in the queue is speakable, it does
         * not start speaking as long as this job is paused.
         *
-        * Depending upon the speech engine and plugin used, speeking may not stop immediately
+        * Depending upon the speech engine and plugin used, speech may not stop immediately
         * (it might finish the current sentence).
         *
         * @see resumeText
@@ -986,13 +1062,17 @@ class KSpeech : virtual public DCOPObject {
         *
         * The job is marked speakable.
         *
-        * If the job was not paused, it is the same as calling @ref startText.
+        * If the job is currently speaking, or is waiting to be spoken (speakable
+        * state), the resumeText() call is ignored.
+        *
+        * If the job is currently queued, or is finished, it is the same as calling
+        * @see startText .
         *
         * If there are speaking jobs preceeding this one in the queue,
         * those jobs continue speaking and when finished this job will begin
         * speaking where it left off.
         *
-        * The @ref textResumed signal is emitted when the job resumes.
+        * The textResumed signal is emitted when the job resumes.
         *
         * @see pauseText
         */
@@ -1090,6 +1170,12 @@ class KSpeech : virtual public DCOPObject {
         * Re-start %KTTSD.
         */
         virtual void reinit() = 0;
+
+        /**
+        * Return the KTTSD deamon version number.
+        * @since KDE 3.5
+        */
+        virtual QString version() = 0;
         //@}
 
     k_dcop_signals:
@@ -1159,7 +1245,7 @@ class KSpeech : virtual public DCOPObject {
         * This signal is emitted whenever a text job is finished.  The job has
         * been marked for deletion from the queue and will be deleted when another
         * job reaches the Finished state. (Only one job in the text queue may be
-        * in state Finished at one time.)  If @ref startText or @ref resumeText is
+        * in state Finished at one time.)  If startText or resumeText is
         * called before the job is deleted, it will remain in the queue for speaking.
         * @param appId          The DCOP senderId of the application that created the job.
         * @param jobNum         Job number of the text job.
