@@ -29,5 +29,5 @@
 
 typedef K_TYPELIST_2( SbdProc, SbdConf ) SbdPlugin;
 K_EXPORT_COMPONENT_FACTORY( libkttsd_sbdplugin,
-    KGenericFactory<SbdPlugin>("kttsd") )
+    KGenericFactory<SbdPlugin>("kttsd_sbd") )
 
