@@ -512,11 +512,6 @@ class Speaker : public QObject{
         */
         QString makeSuggestedFilename();
 
-        /**
-        * Get the real path of a filename and convert it to local encoding.
-        */
-        QString getRealFilePath(const QString filename);
-
         /**
         * Creates and returns a player object based on user option.
         */
@@ -587,6 +582,18 @@ class Speaker : public QObject{
         QCString m_lastAppId;
         uint m_lastSeq;
 
+        /**
+        * Some parameters used by ALSA plugin.
+        * Size of buffer interrupt period (in frames)
+        * Number of periods in buffer.
+        */
+        uint m_periodSize;
+        uint m_periods;
+
+        /**
+        * Debug level in players.
+        */
+        uint m_playerDebugLevel;
 };
 
 #endif // _SPEAKER_H_
