@@ -20,4 +20,4 @@
 #include "hadifixproc.h"
 
 typedef K_TYPELIST_2( HadifixProc, HadifixConf ) Hadifix;
-K_EXPORT_COMPONENT_FACTORY( libkttsd_hadifixplugin, KGenericFactory<Hadifix>("kttsd_hadifixplugin") );
+K_EXPORT_COMPONENT_FACTORY( libkttsd_hadifixplugin, KGenericFactory<Hadifix>("kttsd_hadifix") )
